==> _private_core_network-1.3.11.tar.gz: lib/network_resources/auth/models/auth_industry.dart <==
class AuthIndustry {
  int? id;
  String? industryName;
  String? defaultAvatarPictureUrl;
  String? pictureUrl;
  List<AuthServiceCatIndustry>? serviceCats;

  AuthIndustry({
    this.id,
    this.industryName,
    this.defaultAvatarPictureUrl,
    this.pictureUrl,
    this.serviceCats,
  });

  AuthIndustry.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    industryName = json["industryName"];
    defaultAvatarPictureUrl = json["defaultAvatarPictureUrl"];
    pictureUrl = json["pictureUrl"];
    serviceCats = json["serviceCats"] == null
        ? null
        : (json["serviceCats"] as List)
            .map((e) => AuthServiceCatIndustry.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["industryName"] = industryName;
    data["defaultAvatarPictureUrl"] = defaultAvatarPictureUrl;
    data["pictureUrl"] = pictureUrl;
    if (serviceCats != null) {
      data["serviceCats"] = serviceCats?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class AuthServiceCatIndustry {
  int? id;
  String? catName;
  int? display;
  String? label;
  String? pictureUrl;
  String? colorCode;
  String? colorCode2;
  int? displayForConfig;
  List<AuthServiceSubcatIndustry>? serviceSubcats;

  AuthServiceCatIndustry(
      {this.id,
      this.catName,
      this.display,
      this.label,
      this.pictureUrl,
      this.colorCode,
      this.colorCode2,
      this.displayForConfig,
      this.serviceSubcats});

  AuthServiceCatIndustry.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    catName = json["catName"];
    display = json["display"];
    label = json["label"];
    pictureUrl = json["pictureUrl"];
    colorCode = json["colorCode"];
    colorCode2 = json["colorCode2"];
    displayForConfig = json["displayForConfig"];
    serviceSubcats = json["serviceSubcats"] == null
        ? null
        : (json["serviceSubcats"] as List)
            .map((e) => AuthServiceSubcatIndustry.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["catName"] = catName;
    _data["display"] = display;
    _data["label"] = label;
    _data["pictureUrl"] = pictureUrl;
    _data["colorCode"] = colorCode;
    _data["colorCode2"] = colorCode2;
    _data["displayForConfig"] = displayForConfig;
    if (serviceSubcats != null) {
      _data["serviceSubcats"] = serviceSubcats?.map((e) => e.toJson()).toList();
    }
    return _data;
  }
}

class AuthServiceSubcatIndustry {
  int? id;
  String? subcatName;
  String? colorCode;
  dynamic colorCode2;
  String? subcatTranslation;
  String? pictureUrl;

  AuthServiceSubcatIndustry({
    this.id,
    this.subcatName,
    this.colorCode,
    this.colorCode2,
    this.subcatTranslation,
    this.pictureUrl,
  });

  AuthServiceSubcatIndustry.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    subcatName = json["subcatName"];
    colorCode = json["colorCode"];
    colorCode2 = json["colorCode2"];
    subcatTranslation = json["subcatTranslation"];
    pictureUrl = json["pictureUrl"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["subcatName"] = subcatName;
    _data["colorCode"] = colorCode;
    _data["colorCode2"] = colorCode2;
    _data["subcatTranslation"] = subcatTranslation;
    _data["pictureUrl"] = pictureUrl;
    return _data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/auth/models/auth_industry.dart <==
class AuthIndustry {
  int? id;
  String? industryName;
  String? defaultAvatarPictureUrl;
  String? pictureUrl;
  List<AuthServiceCatIndustry>? serviceCats;

  AuthIndustry({
    this.id,
    this.industryName,
    this.defaultAvatarPictureUrl,
    this.pictureUrl,
    this.serviceCats,
  });

  AuthIndustry.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    industryName = json["industryName"];
    defaultAvatarPictureUrl = json["defaultAvatarPictureUrl"];
    pictureUrl = json["pictureUrl"];
    serviceCats = json["serviceCats"] == null
        ? null
        : (json["serviceCats"] as List)
            .map((e) => AuthServiceCatIndustry.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["industryName"] = industryName;
    data["defaultAvatarPictureUrl"] = defaultAvatarPictureUrl;
    data["pictureUrl"] = pictureUrl;
    if (serviceCats != null) {
      data["serviceCats"] = serviceCats?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class AuthServiceCatIndustry {
  int? id;
  String? catName;
  int? display;
  String? label;
  String? pictureUrl;
  String? colorCode;
  String? colorCode2;
  int? displayForConfig;
  List<AuthServiceSubcatIndustry>? serviceSubcats;

  AuthServiceCatIndustry(
      {this.id,
      this.catName,
      this.display,
      this.label,
      this.pictureUrl,
      this.colorCode,
      this.colorCode2,
      this.displayForConfig,
      this.serviceSubcats});

  AuthServiceCatIndustry.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    catName = json["catName"];
    display = json["display"];
    label = json["label"];
    pictureUrl = json["pictureUrl"];
    colorCode = json["colorCode"];
    colorCode2 = json["colorCode2"];
    displayForConfig = json["displayForConfig"];
    serviceSubcats = json["serviceSubcats"] == null
        ? null
        : (json["serviceSubcats"] as List)
            .map((e) => AuthServiceSubcatIndustry.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["catName"] = catName;
    data["display"] = display;
    data["label"] = label;
    data["pictureUrl"] = pictureUrl;
    data["colorCode"] = colorCode;
    data["colorCode2"] = colorCode2;
    data["displayForConfig"] = displayForConfig;
    if (serviceSubcats != null) {
      data["serviceSubcats"] = serviceSubcats?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class AuthServiceSubcatIndustry {
  int? id;
  String? subcatName;
  String? colorCode;
  dynamic colorCode2;
  String? subcatTranslation;
  String? pictureUrl;

  AuthServiceSubcatIndustry({
    this.id,
    this.subcatName,
    this.colorCode,
    this.colorCode2,
    this.subcatTranslation,
    this.pictureUrl,
  });

  AuthServiceSubcatIndustry.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    subcatName = json["subcatName"];
    colorCode = json["colorCode"];
    colorCode2 = json["colorCode2"];
    subcatTranslation = json["subcatTranslation"];
    pictureUrl = json["pictureUrl"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["subcatName"] = subcatName;
    data["colorCode"] = colorCode;
    data["colorCode2"] = colorCode2;
    data["subcatTranslation"] = subcatTranslation;
    data["pictureUrl"] = pictureUrl;
    return data;
  }
}
